import 'package:flutter/material.dart';

class AlertCircleDialogConstant {
  AlertCircleDialogConstant._();

  static const double padding = 8.0;
  static const double paddingHorizontal = 16.0;
  static const double avatarRadius = 33.0;
}

class AlertCircleDialog extends StatelessWidget {
  final String title;
  final String description;
  final Image image;
  final IconData iconCircle;
  final Color iconColor;
  final Color iconBackgroundColor;
  final Widget content;
  final List<Widget> actions;

  AlertCircleDialog({
    @required this.title,
    @required this.description,
    @required this.iconCircle,
    @required this.iconBackgroundColor,
    @required this.iconColor,
    @required this.content,
    @required this.actions,
    this.image,
  });

  @override
  Widget build(BuildContext context) {
    return Dialog(
      shape: RoundedRectangleBorder(
        borderRadius: BorderRadius.circular(AlertCircleDialogConstant.padding),
      ),
      elevation: 0.0,
      backgroundColor: Colors.transparent,
      child: _dialogContent(context),
    );
  }

  _dialogContent(BuildContext context) {
    return Stack(
      children: <Widget>[
        //...bottom card part,
        _bottomCard(context),
        //...top circle image part,
        _circleImg(),
      ],
    );
  }

  Widget _circleImg() {
    return Positioned(
      left: AlertCircleDialogConstant.padding,
      right: AlertCircleDialogConstant.padding,
      child: CircleAvatar(
        backgroundColor: iconBackgroundColor,
        radius: AlertCircleDialogConstant.avatarRadius,
        child: Icon(
          iconCircle,
          color: iconColor,
          size: 36,
        ),
      ),
    );
  }

  Widget _bottomCard(BuildContext context) {
    return Container(
      padding: EdgeInsets.only(
        top: AlertCircleDialogConstant.padding,
        bottom: AlertCircleDialogConstant.padding,
        left: AlertCircleDialogConstant.paddingHorizontal,
        right: AlertCircleDialogConstant.paddingHorizontal,
      ),
      margin: EdgeInsets.only(top: AlertCircleDialogConstant.avatarRadius),
      decoration: new BoxDecoration(
        color: Colors.white,
        shape: BoxShape.rectangle,
        borderRadius: BorderRadius.circular(AlertCircleDialogConstant.padding),
        boxShadow: [
          BoxShadow(
            color: Colors.black26,
            blurRadius: 10.0,
            offset: const Offset(0.0, 10.0),
          ),
        ],
      ),
      child: Column(
        mainAxisSize: MainAxisSize.min, // To make the card compact
        children: <Widget>[
          title.length == 0 ? SizedBox() : SizedBox(height: 36.0),
          Text(
            title,
            style: TextStyle(
              fontSize: 20.0,
              fontWeight: FontWeight.bold,
            ),
          ),
          title.length == 0 ? SizedBox(height: 4.0) : SizedBox(height: 16.0),
          Text(
            description,
            textAlign: TextAlign.center,
            style: TextStyle(
              fontSize: 16.0,
            ),
          ),
          content,
          SizedBox(height: 12.0),
          if (actions != null)
            ButtonBar(
              children: actions,
            ),
        ],
      ),
    );
  }
}
