import 'dart:async';
import 'dart:convert';

import 'package:hqsoft_core/core_base/core_base.dart';
import 'package:hqsoft_core/data_base/data_base.dart';
import 'package:http/io_client.dart';

class UserApiClient extends Service {
  Future<ResultTokenLogin> login(
      String countryCode, String userName, String password) async {
    String url = await getServiceAPI() + API_IDENTITY_URL.IDENTITY_LOGIN_URL;

    IOClient ioClient = createHttpClient();
    Map<String, String> createRequestHeader =
        await createHeaderUnAuthorization();

    BodyRequestLogin bodyRequestLogin =
        await BodyRequestGeneralBase.createBodyRequestLogin(
            countryCode, userName, password);

    var response = await ioClient
        .post(url,
            headers: createRequestHeader, body: jsonEncode(bodyRequestLogin))
        .timeout(Duration(seconds: serviceTimeOut));

    if (response.statusCode != 200) {
      throw (handleErrorToString(
          response.statusCode, response.body.toString()));
    }

    ResultTokenLogin resultTokenLogin = new ResultTokenLogin();
    resultTokenLogin.countryCode = countryCode;
    resultTokenLogin.phone = userName;
    resultTokenLogin.identity = countryCode + userName;
    resultTokenLogin.token = Service.parseStringBody(response.body);
    resultTokenLogin.password = password;
    return resultTokenLogin;
  }

  Future<UserAppToken> createUserAppTokenFCM(
      String tokenAuthor, String userId, String appId, String tokenFCM) async {
    String url = await getServiceAPI() +
        API_USER_APP_TOKEN_URL.CREATE_USER_APP_TOKEN_URL;

    IOClient ioClient = createHttpClient();
    Map<String, String> createRequestHeader =
        await createHeaderAuthorizationRequiredToken(tokenAuthor);

    BodyRequestCreateUserAppToken bodyRequestCreateUserAppToken =
        await BodyRequestGeneralBase.createBodyRequestCreateUserAppToken(
            userId, appId, tokenFCM);

    final response = await ioClient
        .post(url,
            headers: createRequestHeader,
            body: jsonEncode(bodyRequestCreateUserAppToken))
        .timeout(Duration(seconds: serviceTimeOut));

    if (!isResponseSuccess(response.statusCode)) {
      throw (handleErrorToString(
          response.statusCode, response.body.toString()));
    }

    UserAppToken userAppToken;
    userAppToken = UserAppToken.fromJson(jsonDecode(response.body));
    return userAppToken;
  }

  Future<bool> updateCreateDateUserAppTokenFCM(
      String tokenAuthor, int id) async {
    String url = await getServiceAPI() +
        API_USER_APP_TOKEN_URL.UPDATE_CREATE_DATE_USER_APP_TOKEN_URL +
        '?id=$id';

    IOClient ioClient = createHttpClient();
    Map<String, String> createRequestHeader =
        await createHeaderAuthorizationRequiredToken(tokenAuthor);

    final response = await ioClient
        .put(url, headers: createRequestHeader)
        .timeout(Duration(seconds: serviceTimeOut));

    return isResponseSuccess(response.statusCode);
  }

  Future<bool> deleteUserAppTokenFCM(int id) async {
    String url = await getServiceAPI() +
        API_USER_APP_TOKEN_URL.DELETE_USER_APP_TOKEN_URL +
        '?id=$id';

    IOClient ioClient = createHttpClient();
    Map<String, String> createRequestHeader = await createHeaderAuthorization();

    var response;
    response = await ioClient
        .delete(url, headers: createRequestHeader)
        .timeout(Duration(seconds: serviceTimeOut));

    return isResponseSuccess(response.statusCode);
  }
}
